"""Add switch workflows.

Revision ID: 0e7e7d749617
Revises: 94d9de9246fe
Create Date: 2024-08-29 15:45:57.581710

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = '0e7e7d749617'
down_revision = '94d9de9246fe'
branch_labels = None
depends_on = None


from orchestrator.migrations.helpers import create_workflow, delete_workflow

new_workflows = [
    {
        "name": "create_switch",
        "target": "CREATE",
        "description": "Create Switch",
        "product_type": "Switch"
    },
    {
        "name": "activate_switch",
        "target": "MODIFY",
        "description": "Activate switch",
        "product_type": "Switch"
    },
    {
        "name": "terminate_switch",
        "target": "TERMINATE",
        "description": "Terminate switch",
        "product_type": "Switch"
    },
    {
        "name": "validate_switch",
        "target": "SYSTEM",
        "description": "Validate switch subscription",
        "product_type": "Switch"
    },
    {
        "name": "create_imported_switch",
        "target": "CREATE",
        "description": "Create Imported Switch",
        "product_type": "ImportedSwitch"
    },
    {
        "name": "import_switch",
        "target": "MODIFY",
        "description": "Import Switch",
        "product_type": "ImportedSwitch"
    },
    {
        "name": "create_lan_switch_interconnect",
        "target": "CREATE",
        "description": "Create LAN Switch Interconnect",
        "product_type": "LanSwitchInterconnect"
    },
    {
        "name": "terminate_lan_switch_interconnect",
        "target": "TERMINATE",
        "description": "Terminate LAN Switch Interconnect",
        "product_type": "LanSwitchInterconnect"
    },
    {
        "name": "validate_lan_switch_interconnect",
        "target": "SYSTEM",
        "description": "Validate LAN Switch Interconnect",
        "product_type": "LanSwitchInterconnect"
    },
    {
        "name": "validate_lan_switch_interconnect",
        "target": "SYSTEM",
        "description": "Validate LAN Switch Interconnect",
        "product_type": "LanSwitchInterconnect"
    },
    {
        "name": "create_imported_lan_switch_interconnect",
        "target": "CREATE",
        "description": "Create Imported LAN Switch Interconnect",
        "product_type": "ImportedLanSwitchInterconnect"
    },
    {
        "name": "import_lan_switch_interconnect",
        "target": "MODIFY",
        "description": "Import LAN Switch Interconnect",
        "product_type": "ImportedLanSwitchInterconnect"
    }
]


def upgrade() -> None:
    conn = op.get_bind()
    for workflow in new_workflows:
        create_workflow(conn, workflow)


def downgrade() -> None:
    conn = op.get_bind()
    for workflow in new_workflows:
        delete_workflow(conn, workflow["name"])
