"""Product blocks for :class:`NREN` Layer 3 Core Service products."""

from orchestrator.domain.base import ProductBlockModel
from orchestrator.types import SubscriptionLifecycle
from pydantic import Field

from gso.products.product_blocks.service_binding_port import (
    ServiceBindingPort,
    ServiceBindingPortInactive,
    ServiceBindingPortProvisioning,
)
from gso.utils.shared_enums import APType


class NRENAccessPortInactive(
    ProductBlockModel, lifecycle=[SubscriptionLifecycle.INITIAL], product_block_name="NRENAccessPort"
):
    """An access port for an R&E :term:`NREN` service that is inactive."""

    ap_type: APType | None = None
    sbp: ServiceBindingPortInactive


class NRENAccessPortProvisioning(NRENAccessPortInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    """An access port for an R&E :term:`NREN` service that is being provisioned."""

    ap_type: APType
    sbp: ServiceBindingPortProvisioning


class NRENAccessPort(NRENAccessPortProvisioning, lifecycle=[SubscriptionLifecycle.ACTIVE]):
    """An access port for an R&E :term:`NREN` service."""

    #: The type of Access Port
    ap_type: APType
    #: The corresponding :term:`SBP` of this Access Port.
    sbp: ServiceBindingPort


class NRENL3CoreServiceBlockInactive(
    ProductBlockModel, lifecycle=[SubscriptionLifecycle.INITIAL], product_block_name="NRENL3CoreServiceBlock"
):
    """An inactive :term:`NREN` L3 Core service subscription. See :class:`NRENL3CoreServiceBlock`."""

    nren_ap_list: list[NRENAccessPortInactive] = Field(default_factory=list)


class NRENL3CoreServiceBlockProvisioning(
    NRENL3CoreServiceBlockInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING]
):
    """A provisioning :term:`NREN` L3 Core Service subscription. See :class:`NRENL3CoreServiceBlock`."""

    nren_ap_list: list[NRENAccessPortProvisioning]  # type: ignore[assignment]


class NRENL3CoreServiceBlock(NRENL3CoreServiceBlockProvisioning, lifecycle=[SubscriptionLifecycle.ACTIVE]):
    """An active :term:`NREN` L3 Core Service subscription block."""

    #: The list of Access Points where this service is present.
    nren_ap_list: list[NRENAccessPort]  # type: ignore[assignment]
